@@ -2,29 +2,26 @@ var indexSectionsWithContent =
 {
   0: "abcdefghimnoprstuvw",
   1: "o",
-  2: "o",
-  3: "bcdfghimnoprstuvw",
-  4: "o",
-  5: "adehosu"
+  2: "bcdfghimnoprstuvw",
+  3: "adehosu",
+  4: "o"
 };
 
 var indexSectionNames =
 {
   0: "all",
   1: "classes",
-  2: "functions",
-  3: "variables",
-  4: "typedefs",
-  5: "groups"
+  2: "variables",
+  3: "groups",
+  4: "pages"
 };
 
 var indexSectionLabels =
 {
   0: "All",
   1: "Data Structures",
-  2: "Functions",
-  3: "Variables",
-  4: "Typedefs",
-  5: "Modules"
+  2: "Variables",
+  3: "Modules",
+  4: "Pages"
 };
 
